@@ -322,14 +322,18 @@ class wxStfBatchDlg : public wxDialog
         id_base=0,
         id_basesd,
         id_threshold,
+        id_slopethresholdtime,
         id_peakzero,
         id_peakbase,
         id_peakthreshold,
+        id_peaktime,
         id_rtLoHi,
         id_innerLoHi,
         id_outerLoHi,
         id_t50,
+        id_t50se,
         id_slopes,
+        id_slopetimes,
         id_latencies,
         id_fit,
 #ifdef WITH_PSLOPE
@@ -371,6 +375,11 @@ public:
      */
     bool PrintThreshold() const {return LookUp(id_threshold).selection;}
 
+    //! Indicates whether the time of slope threshold crossing should be printed in the batch analysis table.
+    /*! \return true if it should be printed, false otherwise.
+     */
+    bool PrintSlopeThresholdTime() const {return LookUp(id_slopethresholdtime).selection;}
+
     //! Indicates whether the peak (from 0) value should be printed in the batch analysis table.
     /*! \return true if it should be printed, false otherwise.
      */
@@ -385,7 +394,12 @@ public:
     /*! \return true if it should be printed, false otherwise.
      */
     bool PrintPeakThreshold() const {return LookUp(id_peakthreshold).selection;}
-    
+
+    //! Indicates whether the peak value (from threshold) should be printed in the batch analysis table.
+    /*! \return true if it should be printed, false otherwise.
+     */
+    bool PrintPeakTime() const {return LookUp(id_peaktime).selection;}
+
     //! Indicates whether the Lo-Hi% rise time should be printed in the batch analysis table.
     /*! \return true if it should be printed, false otherwise.
      */
@@ -401,16 +415,26 @@ public:
      */
     bool PrintOuterRTLoHi() const {return LookUp(id_outerLoHi).selection;}
 
-    //! Indicates whether the half duration should be printed in the batch analysis table.
+    //! Indicates whether the half amplitude duration should be printed in the batch analysis table.
     /*! \return true if it should be printed, false otherwise.
      */
     bool PrintT50() const {return  LookUp(id_t50).selection;}
 
+    //! Indicates whether the start and end time for half amplitude should be printed in the batch analysis table.
+    /*! \return true if it should be printed, false otherwise.
+     */
+    bool PrintT50SE() const {return  LookUp(id_t50se).selection;}
+
     //! Indicates whether the maximal slopes should be printed in the batch analysis table.
     /*! \return true if it should be printed, false otherwise.
      */
     bool PrintSlopes() const {return  LookUp(id_slopes).selection;}
 
+    //! Indicates whether the peak value (from threshold) should be printed in the batch analysis table.
+    /*! \return true if it should be printed, false otherwise.
+     */
+    bool PrintSlopeTimes() const {return LookUp(id_slopetimes).selection;}
+
 #ifdef WITH_PSLOPE
     //! Indicates whether the slopes should be printed in the batch analysis table.
     /*! \return true if it should be printed, false otherwise.
